#
# spec file for package dmenu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dmenu
Version:        5.3
Release:        1.5
Summary:        A generic and efficient menu for X
License:        MIT
Group:          System/GUI/Other
URL:            https://tools.suckless.org/dmenu/
Source:         http://dl.suckless.org/tools/%{name}-%{version}.tar.gz
Patch0:         dmenu-optflags.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xft) >= 2.3.5
BuildRequires:  pkgconfig(xinerama)

%description
dmenu is a dynamic menu for X, originally designed for dwm. It manages
large numbers of user-defined menu items efficiently.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%make_build X11LIB="%{_prefix}/X11R6/%{_lib}"

%install
%make_install \
  PREFIX="%{_prefix}"\
  DESTDIR=%{buildroot}

%files
%license LICENSE
%doc README
%{_bindir}/dmenu
%{_bindir}/dmenu_path
%{_bindir}/dmenu_run
%{_bindir}/stest
%{_mandir}/man1/dmenu.1%{?ext_man}
%{_mandir}/man1/stest.1%{?ext_man}

%changelog
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 5.3:
  * fix leak when getline fails
  * readstdin: allocate amount of items
  * readstdin: reduce memory-usage
  * fix BadMatch error when embedding on some windows
  * drw: minor improvement to the nomatches cache
  * remove options target
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to 5.2:
  * dmenu: use die() to print usage message
  * remove workaround for a crash in emojis, fixed in Xft 2.3.5
  * tab-complete: determine size before copying
  * readstdin: use getline
  * improve correctness and startup performance
  * drw_text: account for fallback fonts in ellipsis width
  * drw_text: don't segfault when called with 0 width
  * fix UB with the function iscntrl()
  * avoid redraw when there's no change
  * inputw: improve correctness and startup performance
  * signifcantly improve performance on large strings
* Wed May 11 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.1
  * inputw: improve correctness and startup performance
  * drw_text: don't segfault when called with 0 width
  * drw_text: improve performance when there's no match
  * significantly improve performance on large strings
  * improve performance of case-insensitive matching
  * add support for more keypad keys
* Sun Sep 20 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.0:
  * no change compared to 4.9 with the extra patches
- remove   0001-Close-when-the-embedding-window-is-destroyed.patch
  0002-fix-crash-when-XOpenIM-returns-NULL.patch
  0003-make-dmenu_path-script-executable.patch
  0004-improve-xopenim-error-message.patch
  0005-revert-IME-support.patch
  0006-Fix-memory-leaks-in-drw.patch (upstream)
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- add input fixes from master branch at https://git.suckless.org/dmenu/ (bsc#1164650):
  0001-Close-when-the-embedding-window-is-destroyed.patch
  0002-fix-crash-when-XOpenIM-returns-NULL.patch
  0003-make-dmenu_path-script-executable.patch
  0004-improve-xopenim-error-message.patch
  0005-revert-IME-support.patch
  0006-Fix-memory-leaks-in-drw.patch
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 4.9
  * Use slow path if stdin is a tty
  * Use bold for keyboard shortcuts in dmenu.1
  * Fix cursor drawn position with wide glyphs
* Thu Mar  5 2020 Tomas Cech <sleep_walker@opensuse.org>
- revert back to 4.8
  Based on bnc#1164650, fixes in GIT and personal experience - reverting.
- refresh dmenu-optflags again
- remove patches:
    0001-Close-when-the-embedding-window-is-destroyed.patch
    0002-fix-crash-when-XOpenIM-returns-NULL.patch
* Mon Feb 24 2020 Tomas Cech <sleep_walker@opensuse.org>
- add 0001-Close-when-the-embedding-window-is-destroyed.patch
- add 0002-fix-crash-when-XOpenIM-returns-NULL.patch
  - fix crash on input
* Mon Feb 24 2020 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Install license and readme file
* Thu Jan 23 2020 Martin Rey <mrey@suse.com>
- bump to 4.9
  for complete list of changes see
  see https://git.suckless.org/dmenu/log/?h=4.9&qt=range&q=4.8..4.9
- dmenu-optflags.patch: Adapt patch to dmenu 4.9
* Sun Apr 15 2018 gutaper@gmail.com
- bump to 4.8
  for complete list of changes see
  see https://git.suckless.org/dmenu/log/?h=4.8&qt=range&q=4.7..4.8
* Fri Feb  9 2018 crrodriguez@opensuse.org
- dmenu-optflags.patch: Fix optflags handling
- Fix BuildRequires not to use xorg-x11-devel
* Wed Jul 26 2017 sleep_walker@opensuse.org
- bump to 4.7
  for complete list of changes see
  see http://git.suckless.org/dmenu/log/?h=4.7&qt=range&q=4.6..4.7
* Mon Nov  9 2015 sleep_walker@opensuse.org
- bump to 4.6
  - no changelog generated for 4 years of development
    so check http://git.suckless.org/dmenu/ by yourself
- add Xft and freetype2 into dependencies to follow changes in this
  new version
* Fri Jul  3 2015 mimi.vx@gmail.com
- spec cleaned with spec-cleaner
* Tue May 15 2012 seiler@b1-systems.de
- added link to dmenu changelog in the *.changes file
* Mon Mar 19 2012 seiler@b1-systems.de
- updated to version 4.5
  Changelog:
  http://hg.suckless.org/dmenu/log
- enhanced description
- removed package name from summary
- added new files to %%file section
* Thu Oct 11 2007 sschober@suse.de
- incorporated latest changeset [231:9ab649b3b3e5]
* Wed Oct  3 2007 sschober@suse.de
- updated to version 3.4
* Fri Jul 27 2007 sschober@suse.de
- initial packaging.
